@@ -5,8 +5,10 @@ echo "Started $0 $@"
 
 set -e -x
 REQUIREMENTS=/io/requirements.txt
-WHEELHOUSE=/io/wheelhouse
+[ -n "$WHEELHOUSE" ] || WHEELHOUSE=wheelhouse
 SDIST=$1
+PACKAGE=$(basename ${SDIST%-*})
+SDIST_PREFIX=$(basename ${SDIST%%.tar.gz})
 
 build_wheel() {
     pybin="$1"
@@ -19,13 +21,13 @@ build_wheel() {
         ${pybin}/pip \
             wheel \
             "$source" \
-            -w $WHEELHOUSE
+            -w /io/$WHEELHOUSE
 }
 
 assert_importable() {
     # Install packages and test
     for PYBIN in /opt/python/*/bin/; do
-        ${PYBIN}/pip install lxml --no-index -f $WHEELHOUSE
+        ${PYBIN}/pip install $PACKAGE --no-index -f /io/$WHEELHOUSE
 
         (cd $HOME; ${PYBIN}/python -c 'import lxml.etree, lxml.objectify')
     done
@@ -43,29 +45,32 @@ build_wheels() {
     test -e "$SDIST" && source="$SDIST" || source=
     FIRST=
     SECOND=
+    THIRD=
     for PYBIN in /opt/python/*/bin; do
         # Install build requirements if we need them and file exists
         test -n "$source" -o ! -e "$REQUIREMENTS" \
             || ${PYBIN}/pip install -r "$REQUIREMENTS"
 
+        echo "Starting build with $($PYBIN/python -V)"
         build_wheel "$PYBIN" "$source" &
-        SECOND=$!
+        THIRD=$!
 
         [ -z "$FIRST" ] || wait ${FIRST}
         FIRST=$SECOND
+        SECOND=$THIRD
     done
     wait
 }
 
 repair_wheels() {
     # Bundle external shared libraries into the wheels
-    for whl in $WHEELHOUSE/*.whl; do
-        auditwheel repair $whl -w $WHEELHOUSE
+    for whl in /io/$WHEELHOUSE/${SDIST_PREFIX}-*.whl; do
+        auditwheel repair $whl -w /io/$WHEELHOUSE
     done
 }
 
 show_wheels() {
-    ls -l $WHEELHOUSE
+    ls -l /io/$WHEELHOUSE/${SDIST_PREFIX}-*.whl
 }
 
 prepare_system
